@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2016 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAccesslogWidgetContainer.php 5802 2013-03-07 06:14:29Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConditionBaseWidgetContainer.php');
@@ -26,13 +26,13 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $clientIp;			// クライアントのIPアドレス
 	private $path;				// アクセスパス
-	private $browserIconFile;	// ブラウザアイコンファイル名
-	private $osIconFile;	// OSアイコンファイル名
 	private $showMessage;		// メッセージ画面かどうか
 	private $message;			// 表示メッセージ
 	private $server;			// 指定サーバ
 	private $startDt;			// 検索範囲開始日付
 	private $endDt;				// 検索範囲終了日付
+	private $browserTypeInfo;	// ブラウザ情報(再利用)
+	private $osInfo;			// プラットフォーム情報(再利用)
 	const DEFAULT_LIST_COUNT = 30;			// 最大リスト表示数
 	const MAX_PAGE_COUNT = 200;				// 最大ページ数
 	const INFO_ICON_FILE = '/images/system/info16.png';			// 情報アイコン
@@ -65,96 +65,6 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
 		$this->serverDb = new admin_serverDb();
-		
-		// ブラウザアイコンファイル名
-		$this->browserIconFile = array(
-			'OP' => 'opera.png',	// opera
-			'IE' => 'ie.png',	// microsoft internet explorer
-			'NS' => 'netscape.png',	// netscape
-			'GA' => 'galeon.png',	// galeon
-			'PX' => 'phoenix.png',	// phoenix
-			'FF' => 'firefox.png',	// firefox
-			'FB' => 'firebird.png',	// mozilla firebird
-			'SM' => 'seamonkey.png',	// seamonkey
-			'CA' => 'camino.png',	// camino
-			'SF' => 'safari.png',	// safari
-			'CH' => 'chrome.gif',	// chrome
-			'KM' => 'k-meleon.png',	// k-meleon
-			'MO' => 'mozilla.gif',	// mozilla
-			'KO' => 'konqueror.png',	// konqueror
-			'BB' => '',	// blackberry
-			'IC' => 'icab.png',	// icab
-			'LX' => '',	// lynx
-			'LI' => '',	// links
-			'MC' => '',	// ncsa mosaic
-			'AM' => '',	// amaya
-			'OW' => 'omniweb.png',	// omniweb
-			'HJ' => '',	// hotjava
-			'BX' => '',	// browsex
-			'AV' => '',	// amigavoyager
-			'AW' => '',	// amiga-aweb
-			'IB' => '',	// ibrowse
-			'AR' => '',	// arora
-			'EP' => 'epiphany.png',	// epiphany
-			'FL' => 'flock.png',	// flock
-			'SL' => 'sleipnir.gif'		,// sleipnir
-			'LU' => 'lunascape.gif',	// lunascape
-			'SH' => 'shiira.gif',		// shiira
-			'SW' => 'swift.png',	// swift
-			'PS' => 'playstation.gif',	// playstation portable
-			'PP' => 'playstation.gif',	// ワイプアウトピュア
-			'NC' => 'netcaptor.gif',	// netcaptor
-			'WT' => 'webtv.gif',	// webtv
-			
-			// クローラ
-			'GB' => 'google.gif',	// Google
-			'MS' => 'msn.gif',	// MSN
-			'YA' => 'yahoo.gif',	// YahooSeeker
-			'GO' => 'goo.gif',	// goo
-			'BD' => 'baidu.png',	// 百度
-			'HT' => 'hatena.gif',	// はてなアンテナ
-			'NV' => 'naver.gif',	// Naver(韓国)
-			'NI' => 'nict.gif',		// 独立行政法人情報通信研究機構
-			'DB' => 'dotbot.gif',		// Dotbot
-			'EW' => 'entireweb.png',		// Entireweb
-			'TB' => 'turnitinbot.png',		// TurnitinBot
-			'BI' => 'bing.png',		// Bing
-			'YC' => 'yacy.png',		// YaCy
-			
-			// 携帯
-			'DC' => 'docomo.gif',		// ドコモ
-			'AU' => 'au.gif',		// au
-			'SB' => 'softbank.gif',		// ソフトバンク
-		);
-		// OSアイコンファイル名
-		$this->osIconFile = array(
-			'IPD' => '',	// iPod
-			'IPH' => '',	// iPhone
-			'WII' => '',	// Nintendo Wii
-			'PSP' => '',	// PlayStation Portable
-			'PS3' => '',	// PlayStation 3
-			'AND' => '',	// Android
-			'POS' => '',	// PalmOS
-			'BLB' => '',	// BlackBerry
-			'WI7' => 'winvista.gif',	// Windows NT 6.1, Windows 7
-			'WVI' => 'winvista.gif',	// Windows NT 6.0, Windows Vista
-			'WS3' => 'win.gif',	// Windows NT 5.2, Windows Server 2003
-			'WXP' => 'win.gif',	// Windows NT 5.1, Windows XP
-			'W98' => 'win98.gif',	// Windows 98
-			'W2K' => 'win.gif',	// Windows NT 5.0, Windows 2000
-			'WNT' => 'win98.gif',	// Windows NT 4.0
-			'WME' => 'win98.gif',	// Win 9x 4.90, Windows ME
-			'W95' => 'win98.gif',	// Windows 95
-			'MAC' => 'osx.gif', 	// Mac PowerPC
-			'LIN' => 'linux.gif',	// Linux
-			'SOS' => 'sun.gif',	// SunOS
-			'BSD' => 'bsd.gif',	// FreeBSD
-			'AIX' => '',	// AIX
-			'IRI' => 'irix.gif',	// IRIX
-			'HPX' => 'hp-ux.gif',	// HP-UX
-			'OS2' => '',	// OS/2
-			'NBS' => 'bsd.gif',	// NetBSD
-		);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -398,45 +308,44 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 					}
 				}
 				// ブラウザ、プラットフォームの情報を取得
-				$isMobile = false;		// 携帯かどうか
-				$browserCode = $this->gInstance->getAnalyzeManager()->getBrowserType($agent, $version);
+				$browserTypeInfo = $this->gInstance->getAnalyzeManager()->getBrowserType($agent);
 				$browserImg = '';
-				if (!empty($browserCode)){
-					$iconFile = $this->browserIconFile[$browserCode];
+				if (!empty($browserTypeInfo)){
+					$iconFile = $browserTypeInfo['icon'];
 					if (!empty($iconFile)){
-						$iconTitle = $browserCode;
+						$iconTitle = $browserTypeInfo['name'];
 						$iconUrl = $this->gEnv->getRootUrl() . self::BROWSER_ICON_DIR . $iconFile;
-						$browserImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+						$browserImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 					}
 				}
-				if ($browserCode == 'DC' ||		// ドコモ
-					$browserCode == 'AU' ||		// au
-					$browserCode == 'SB'){		// ソフトバンク
-					$isMobile = true;
-				}
 		
 				// アクセスユーザの国を取得
 				$countryCode = '';
 				if (!empty($language)) $countryCode = $this->gInstance->getAnalyzeManager()->getBrowserCountryCode($language);
-				if ($isMobile) $countryCode = 'jp';		// 携帯の場合は日本に設定
 		
 				$countryImg = '';
 				if (!empty($countryCode)){
 					$iconTitle = $countryCode;
 					$iconUrl = $this->gEnv->getRootUrl() . self::FLAG_ICON_DIR . $countryCode . '.png';
-					$countryImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+					$countryImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 				}
 		
 				$osImg = '';			// OS
-				$osCode = $this->gInstance->getAnalyzeManager()->getPlatformType($agent, $version);
-				if (!$isMobile){		// 携帯以外の場合
-					if (!empty($osCode)){
-						$iconFile = $this->osIconFile[$osCode];	// OSアイコンファイル名
-						if (!empty($iconFile)){
-							$iconTitle = $osCode;
-							$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
-							$osImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-						}
+				$osInfo = $this->gInstance->getAnalyzeManager()->getPlatformType($agent);
+/*				if (!empty($osCode)){
+					$iconFile = $this->osIconFile[$osCode];	// OSアイコンファイル名
+					if (!empty($iconFile)){
+						$iconTitle = $osCode;
+						$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
+						$osImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+					}
+				}*/
+				if (!empty($osInfo)){
+					$iconFile = $osInfo['icon'];	// OSアイコンファイル名
+					if (!empty($iconFile)){
+						$iconTitle = $osInfo['name'] . ' ' . $osInfo['version_name'];
+						$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
+						$osImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 					}
 				}
 			}
@@ -483,7 +392,10 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 	 */
 	function logListLoop($index, $fetchedRow, $param)
 	{
+		static $savedAgent;		// 前ブラウザ情報退避用
+		
 		$serial = $fetchedRow['al_serial'];
+		$agent = $fetchedRow['al_user_agent'];
 		
 		$ip = $fetchedRow['al_ip'];
 		$ipStr = $this->convertToDispString($ip);
@@ -492,45 +404,44 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		}
 		
 		// ブラウザ、プラットフォームの情報を取得
-		$isMobile = false;		// 携帯かどうか
-		$browserCode = $this->gInstance->getAnalyzeManager()->getBrowserType($fetchedRow['al_user_agent'], $version);
+		if ($agent != $savedAgent) $this->browserTypeInfo = $this->gInstance->getAnalyzeManager()->getBrowserType($agent);
 		$browserImg = '';
-		if (!empty($browserCode)){
-			$iconFile = $this->browserIconFile[$browserCode];
+		if (!empty($this->browserTypeInfo)){
+			$iconFile = $this->browserTypeInfo['icon'];
 			if (!empty($iconFile)){
-				$iconTitle = $browserCode;
+				$iconTitle = $this->browserTypeInfo['name'];
 				$iconUrl = $this->gEnv->getRootUrl() . self::BROWSER_ICON_DIR . $iconFile;
-				$browserImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+				$browserImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 			}
 		}
-		if ($browserCode == 'DC' ||		// ドコモ
-			$browserCode == 'AU' ||		// au
-			$browserCode == 'SB'){		// ソフトバンク
-			$isMobile = true;
-		}
 		
 		// アクセスユーザの国を取得
 		$countryCode = '';
 		if (!empty($fetchedRow['al_accept_language'])) $countryCode = $this->gInstance->getAnalyzeManager()->getBrowserCountryCode($fetchedRow['al_accept_language']);
-		if ($isMobile) $countryCode = 'jp';		// 携帯の場合は日本に設定
 		
 		$countryImg = '';
 		if (!empty($countryCode)){
 			$iconTitle = $countryCode;
 			$iconUrl = $this->gEnv->getRootUrl() . self::FLAG_ICON_DIR . $countryCode . '.png';
-			$countryImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+			$countryImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 		}
 		
 		$osImg = '';			// OS
-		$osCode = $this->gInstance->getAnalyzeManager()->getPlatformType($fetchedRow['al_user_agent'], $version);
-		if (!$isMobile){		// 携帯以外の場合
-			if (!empty($osCode)){
-				$iconFile = $this->osIconFile[$osCode];	// OSアイコンファイル名
-				if (!empty($iconFile)){
-					$iconTitle = $osCode;
-					$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
-					$osImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-				}
+		if ($agent != $savedAgent) $this->osInfo = $this->gInstance->getAnalyzeManager()->getPlatformType($agent);
+/*		if (!empty($osCode)){
+			$iconFile = $this->osIconFile[$osCode];	// OSアイコンファイル名
+			if (!empty($iconFile)){
+				$iconTitle = $osCode;
+				$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
+				$osImg = '<img src="' . $this->getUrl($iconUrl) . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+			}
+		}*/
+		if (!empty($this->osInfo)){
+			$iconFile = $this->osInfo['icon'];	// OSアイコンファイル名
+			if (!empty($iconFile)){
+				$iconTitle = $this->osInfo['name'] . ' ' . $this->osInfo['version_name'];
+				$iconUrl = $this->gEnv->getRootUrl() . self::OS_ICON_DIR . $iconFile;
+				$osImg = '<img src="' . $this->getUrl($iconUrl) . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 			}
 		}
 
@@ -553,6 +464,9 @@ class admin_mainAccesslogWidgetContainer extends admin_mainConditionBaseWidgetCo
 		$this->tmpl->addVars('loglist', $row);
 		$this->tmpl->parseTemplate('loglist', 'a');
 		
+		// ブラウザ情報退避
+		$savedAgent = $agent;		// 前ブラウザ情報退避用
+		
 		// 表示中のコンテンツIDを保存
 		$this->serialArray[] = $serial;
 		return true;
