@@ -35,6 +35,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 	const DEFAULT_TITLE = 'カスタム検索';			// デフォルトのウィジェットタイトル
 	const FIELD_HEAD = 'item';			// フィールド名の先頭文字列
 	const DEFAULT_SEARCH_COUNT	= 20;				// デフォルトの検索結果表示数
+	const DEFAULT_IMAGE_FILENAME_HEAD = 'default';		// デフォルトの画像ファイル名ヘッダ
 	const DEFAULT_IMAGE_TYPE = '80c.jpg';		// デフォルトの画像タイプ
 	const LINK_PAGE_COUNT		= 5;			// リンクページ数
 	const MESSAGE_NO_KEYWORD	= '検索キーワードが入力されていません';
@@ -212,7 +213,8 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 				// リンク文字列作成、ページ番号調整
 				$linkStyle = 0;			// HTMLの出力タイプ
 				if ($this->templateType == M3_TEMPLATE_BOOTSTRAP_30) $linkStyle = 2;		// Bootstrap型テンプレートの場合
-				$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $this->currentPageUrl . '&act=' . self::DEFAULT_SEARCH_ACT . '&keyword=' . urlencode($keyword),
+	//			$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $this->currentPageUrl . '&act=' . self::DEFAULT_SEARCH_ACT . '&keyword=' . urlencode($keyword),
+				$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $this->currentPageUrl . '&task=search&keyword=' . urlencode($keyword),
 													''/*追加パラメータなし*/, $linkStyle);
 
 				// ##### 作成されたページリンク情報を取得 #####
@@ -591,9 +593,12 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		$escapedLinkUrl = $this->convertUrlToHtmlEntity($linkUrl);
 		if (!empty($linkUrl)) $titleLink = '<a href="' . $escapedLinkUrl . '" >' . $titleLink . '</a>';
 
+		// 画像がない場合はデフォルト画像を取得
+		if (empty($imageUrl)) $imageUrl = $this->getDefaultImageUrl($this->imageType);
+		
 		// 画像
 		$imageTag = '';
-		if ($this->showImage && !empty($imageUrl)){
+		if ($this->showImage && !empty($imageUrl)){	// サムネール画像を表示する場合
 			$style = '';
 			if ($this->imageWidth > 0) $style .= 'width:' . $this->imageWidth . 'px;';
 			if ($this->imageHeight > 0) $style .= 'height:' . $this->imageHeight . 'px;';
@@ -630,7 +635,11 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		$viewItem->text			= $viewItem->introtext;	// コンテンツ内容(Joomla!1.5テンプレート用)
 		$viewItem->state		= 1;			// 表示モード(0=新着,1=表示済み)
 		$viewItem->url			= $linkUrl;						// リンク先。viewItem->urlはMagic3の拡張値。
-
+		if ($this->showImage && !empty($imageUrl)){	// サムネール画像を表示する場合
+			$viewItem->thumbUrl	= $imageUrl;
+			$viewItem->thumbAlt	= $title;
+		}
+		
 //		// 以下は表示する項目のみ値を設定する
 //		if ($this->showEntryAuthor) $viewItem->author		= $author;		// 投稿者
 //		if ($this->showEntryRegistDt) $viewItem->published	= $date;		// 投稿日時
@@ -753,6 +762,18 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		}
 		return $url;
 	}
+	/**
+	 * デフォルトの画像のURLを取得
+	 *
+	 * @param string $format		画像フォーマット
+	 * @return string				URL
+	 */
+	function getDefaultImageUrl($format)
+	{
+		$filename = $this->gInstance->getImageManager()->getThumbFilename(self::DEFAULT_IMAGE_FILENAME_HEAD, $format);
+		$url = $this->gInstance->getImageManager()->getSystemThumbUrl(M3_VIEW_TYPE_SEARCH, 0/*PC用*/, $filename);
+		return $url;
+	}
 	/**
 	 * トップメッセージを追加
 	 *
